==> sftp_uploader-1.0.0.tar.gz: sftp_uploader-1.0.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sftp_uploader',
 'sftp_uploader.applications',
 'sftp_uploader.constants.applications',
 'sftp_uploader.services',
 'sftp_uploader.services.applications',
 'sftp_uploader.services.exceptions']

package_data = \
{'': ['*']}

install_requires = \
['dependency-injector>=4.41.0,<5.0.0',
 'gitpython>=3.1.31,<4.0.0',
 'paramiko>=3.1.0,<4.0.0',
 'pydantic>=1.10.7,<2.0.0',
 'python-dotenv>=1.0.0,<2.0.0']

entry_points = \
{'console_scripts': ['post_install = sftp_uploader.setup_actions:run']}

setup_kwargs = {
    'name': 'sftp-uploader',
    'version': '1.0.0',
    'description': 'Package for upload data to sftp with different parametrs and with different methods',
    'long_description': '# TODO\n\n[ ] Make title, description, which problem is solve, metter of this project description\n\n[ ] Add more [classifiers](https://pypi.org/classifiers/)\n\n[ ] Add tests\n\n[ ] Add additional links to project conf\n\n[ ] Add poetry scripts and pre-commit scripts\n\n[ ] Add poetry post install, if git exists andd to gitignore and setup pre commit hook, and setup config module, if not exists, create and setup it\n',
    'author': 'Moonvent',
    'author_email': 'moonvent@proton.me',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/moonvent/sftp_uploader/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.11,<4.0',
}


setup(**setup_kwargs)

==> sftp_uploader-1.0.1.tar.gz: sftp_uploader-1.0.1/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['sftp_uploader',
 'sftp_uploader.applications',
 'sftp_uploader.constants.applications',
 'sftp_uploader.services',
 'sftp_uploader.services.applications',
 'sftp_uploader.services.exceptions']

package_data = \
{'': ['*']}

install_requires = \
['dependency-injector>=4.41.0,<5.0.0',
 'gitpython>=3.1.31,<4.0.0',
 'paramiko>=3.1.0,<4.0.0',
 'pydantic>=1.10.7,<2.0.0',
 'python-dotenv>=1.0.0,<2.0.0']

entry_points = \
{'console_scripts': ['post_install = '
                     'sftp_uploader.poetry_post_install_actions:poetry_post_install_actions']}

setup_kwargs = {
    'name': 'sftp-uploader',
    'version': '1.0.1',
    'description': 'Package for upload data to sftp with different parametrs and with different methods',
    'long_description': '# TODO\n\n[ ] Make title, description, which problem is solve, metter of this project description\n\n[ ] Add more [classifiers](https://pypi.org/classifiers/)\n\n[ ] Add tests\n\n[ ] Add additional links to project conf\n\n[ ] Add poetry scripts and pre-commit scripts\n\n[ ] Add poetry post install, if git exists andd to gitignore and setup pre commit hook, and setup config module, if not exists, create and setup it\n',
    'author': 'Moonvent',
    'author_email': 'moonvent@proton.me',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/moonvent/sftp_uploader/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.11,<4.0',
}


setup(**setup_kwargs)
